<?php
/**
 * Add primary menu element settings.
 *
 * @package Verve Blog
 */

$fields = [
    'footer_menu_group_fields' => [
        'type'              => 'group-field',
        'section'           => 'footer_menu_1_element_section',
        'priority'          => 5,
        'tabs'              => [
            'desktop'            => [
                'nicename'      => esc_html__( '&gt; 1100px', 'verve-blog' ),
                'preview'       => 'desktop',
                'active_tab'    => true,
                'controls'      => [
                    'footer_menu_sep',
                    'footer_menu_assign',
                    'footer_menu_sep_1',
                    'footer_menu_spacing',
                    'footer_menu_container_sep',
                    'footer_menu_container_padding',
                    'footer_menu_container_margin'
                ]
            ],
            'tablet'            => [
                'nicename'      => esc_html__( '&gt; 768px', 'verve-blog' ),
                'preview'       => 'tablet',
                'active_tab'    => false,
                'controls'      => [
                    'footer_menu_container_sep',
                    'footer_menu_container_md_padding',
                    'footer_menu_container_md_margin'
                ]
            ],
            'mobile'            => [
                'nicename'      => esc_html__( '&lt; 576px', 'verve-blog' ),
                'preview'       => 'mobile',
                'active_tab'    => false,
                'controls'      => [
                    'footer_menu_container_sep',
                    'footer_menu_container_sm_padding',
                    'footer_menu_container_sm_margin'
                ]
            ]
        ],
    ],
    'footer_menu_sep' => [
        'type'              => 'custom',
        'section'           => 'footer_menu_1_element_section',
        'default'           => '<h3 style="border-width:1px 0;border-style: solid;border-color: #fff;margin:0 -11px;padding: 8px 12px;background: #fff;">' . esc_html__( 'CONTENT', 'verve-blog' ) . '</h3>',
        'priority'          => 10
    ],
    'footer_menu_assign' => [
        'type'              => 'custom',
        'section'           => 'footer_menu_1_element_section',
        'default'           => '<h3 data-type="section" data-id="menu_locations" class="customizer-focus" style="border-width:1px 0;border-style: solid;border-color: #fff;margin:0;padding: 8px 12px;background: #fff;">' . esc_html__( 'Select Menu &raquo;', 'verve-blog' ) . '</h3>',
        'priority'          => 10
    ],
    'footer_menu_sep_1' => [
        'type'              => 'custom',
        'section'           => 'footer_menu_1_element_section',
        'default'           => '<h3 style="border-width:1px 0;border-style: solid;border-color: #fff;margin:0 -11px;padding: 8px 12px;background: #fff;">' . esc_html__( 'Menu Item', 'verve-blog' ) . '</h3>',
        'priority'          => 10
    ],
    'footer_menu_spacing' => [
        'type'              => 'slider',
        'label'             => esc_html__( 'Spacing', 'verve-blog' ),
        'description'       => esc_html__( 'Set gap between each menu item.', 'verve-blog' ),
        'section'           => 'footer_menu_1_element_section',
        'default'           => 30,
        'choices'           => [
            'min'               => 0,
            'max'               => 100,
            'step'              => 1,
            'suffix'            => 'px'
        ],
        'priority'          => 10,
        'transport'         => 'auto',
        'output'            => [
            [
	            'property'      => 'margin-right',
                'element'       => '.site-footer div#footer-menu ul > li:not(:last-child)',
                'suffix'        => 'px'
            ]
        ],
    ],
    'footer_menu_container_sep' => [
        'type'              => 'custom',
        'section'           => 'footer_menu_1_element_section',
        'default'           => '<h3 style="border-width:1px 0;border-style: solid;border-color: #fff;margin:0 -11px;padding: 8px 12px;background: #fff;">' . esc_html__( 'CONTAINER SETTING', 'verve-blog' ) . '</h3>',
        'priority'          => 10
    ],
    'footer_menu_container_padding' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Padding', 'verve-blog' ),
        'description' => esc_html__( 'Set container padding.', 'verve-blog' ),
        'section'     => 'footer_menu_1_element_section',
        'priority'    => 10,
        'default'     => [
            'padding-top'    => '',
            'padding-bottom' => '',
            'padding-left'   => '',
            'padding-right'  => '',
        ],
        'choices'     => [
            'labels'    => [
                'padding-top'    => esc_html__( 'Top', 'verve-blog' ),
                'padding-bottom' => esc_html__( 'Bottom', 'verve-blog' ),
                'padding-left'   => esc_html__( 'Left', 'verve-blog' ),
                'padding-right'  => esc_html__( 'Right', 'verve-blog' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'choice'    => 'padding-top',
                'property'  => 'padding-top',
                'element'   => 'site-footer #footer-menu',
            ],
            [
                'choice'    => 'padding-bottom',
                'property'  => 'padding-bottom',
                'element'   => 'site-footer #footer-menu',
            ],
            [
                'choice'    => 'padding-left',
                'property'  => 'padding-left',
                'element'   => 'site-footer #footer-menu',
            ],
            [
                'choice'    => 'padding-right',
                'property'  => 'padding-right',
                'element'   => 'site-footer #footer-menu',
            ],
        ],
    ],
    'footer_menu_container_md_padding' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Padding', 'verve-blog' ),
        'description' => esc_html__( 'Set container padding.', 'verve-blog' ),
        'section'     => 'footer_menu_1_element_section',
        'priority'    => 10,
        'default'     => [
            'padding-top'    => '',
            'padding-bottom' => '',
            'padding-left'   => '',
            'padding-right'  => '',
        ],
        'choices'     => [
            'labels'    => [
                'padding-top'    => esc_html__( 'Top', 'verve-blog' ),
                'padding-bottom' => esc_html__( 'Bottom', 'verve-blog' ),
                'padding-left'   => esc_html__( 'Left', 'verve-blog' ),
                'padding-right'  => esc_html__( 'Right', 'verve-blog' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'padding-top',
                'property'      => 'padding-top',
                'element'       => 'site-footer #footer-menu',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'padding-bottom',
                'property'      => 'padding-bottom',
                'element'       => 'site-footer #footer-menu',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'padding-left',
                'property'      => 'padding-left',
                'element'       => 'site-footer #footer-menu',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'padding-right',
                'property'      => 'padding-right',
                'element'       => 'site-footer #footer-menu',
            ],
        ],
    ],
    'footer_menu_container_sm_padding' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Padding', 'verve-blog' ),
        'description' => esc_html__( 'Set container padding.', 'verve-blog' ),
        'section'     => 'footer_menu_1_element_section',
        'priority'    => 10,
        'default'     => [
            'padding-top'    => '',
            'padding-bottom' => '',
            'padding-left'   => '',
            'padding-right'  => '',
        ],
        'choices'     => [
            'labels'    => [
                'padding-top'    => esc_html__( 'Top', 'verve-blog' ),
                'padding-bottom' => esc_html__( 'Bottom', 'verve-blog' ),
                'padding-left'   => esc_html__( 'Left', 'verve-blog' ),
                'padding-right'  => esc_html__( 'Right', 'verve-blog' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'padding-top',
                'property'      => 'padding-top',
                'element'       => 'site-footer #footer-menu',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'padding-bottom',
                'property'      => 'padding-bottom',
                'element'       => 'site-footer #footer-menu',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'padding-left',
                'property'      => 'padding-left',
                'element'       => 'site-footer #footer-menu',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'padding-right',
                'property'      => 'padding-right',
                'element'       => 'site-footer #footer-menu',
            ],
        ],
    ],
    'footer_menu_container_margin' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Margin', 'verve-blog' ),
        'description' => esc_html__( 'Set container margin.', 'verve-blog' ),
        'section'     => 'footer_menu_1_element_section',
        'priority'    => 10,
        'default'     => [
            'margin-top'    => '',
            'margin-bottom' => '',
            'margin-left'   => '',
            'margin-right'  => '',
        ],
        'choices'     => [
            'labels'    => [
                'margin-top'    => esc_html__( 'Top', 'verve-blog' ),
                'margin-bottom' => esc_html__( 'Bottom', 'verve-blog' ),
                'margin-left'   => esc_html__( 'Left', 'verve-blog' ),
                'margin-right'  => esc_html__( 'Right', 'verve-blog' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'choice'    => 'margin-top',
                'property'  => 'margin-top',
                'element'   => 'site-footer #footer-menu',
            ],
            [
                'choice'    => 'margin-bottom',
                'property'  => 'margin-bottom',
                'element'   => 'site-footer #footer-menu',
            ],
            [
                'choice'    => 'margin-left',
                'property'  => 'margin-left',
                'element'   => 'site-footer #footer-menu',
            ],
            [
                'choice'    => 'margin-right',
                'property'  => 'margin-right',
                'element'   => 'site-footer #footer-menu',
            ],
        ],
    ],
    'footer_menu_container_md_margin' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Margin', 'verve-blog' ),
        'description' => esc_html__( 'Set container margin.', 'verve-blog' ),
        'section'     => 'footer_menu_1_element_section',
        'priority'    => 10,
        'default'     => [
            'margin-top'    => '',
            'margin-bottom' => '',
            'margin-left'   => '',
            'margin-right'  => '',
        ],
        'choices'     => [
            'labels'    => [
                'margin-top'    => esc_html__( 'Top', 'verve-blog' ),
                'margin-bottom' => esc_html__( 'Bottom', 'verve-blog' ),
                'margin-left'   => esc_html__( 'Left', 'verve-blog' ),
                'margin-right'  => esc_html__( 'Right', 'verve-blog' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'margin-top',
                'property'      => 'margin-top',
                'element'       => 'site-footer #footer-menu',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'margin-bottom',
                'property'      => 'margin-bottom',
                'element'       => 'site-footer #footer-menu',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'margin-left',
                'property'      => 'margin-left',
                'element'       => 'site-footer #footer-menu',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'margin-right',
                'property'      => 'margin-right',
                'element'       => 'site-footer #footer-menu',
            ],
        ],
    ],
    'footer_menu_container_sm_margin' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Margin', 'verve-blog' ),
        'description' => esc_html__( 'Set container margin.', 'verve-blog' ),
        'section'     => 'footer_menu_1_element_section',
        'priority'    => 10,
        'default'     => [
            'margin-top'    => '',
            'margin-bottom' => '',
            'margin-left'   => '',
            'margin-right'  => '',
        ],
        'choices'     => [
            'labels'    => [
                'margin-top'    => esc_html__( 'Top', 'verve-blog' ),
                'margin-bottom' => esc_html__( 'Bottom', 'verve-blog' ),
                'margin-left'   => esc_html__( 'Left', 'verve-blog' ),
                'margin-right'  => esc_html__( 'Right', 'verve-blog' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'margin-top',
                'property'      => 'margin-top',
                'element'       => 'site-footer #footer-menu',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'margin-bottom',
                'property'      => 'margin-bottom',
                'element'       => 'site-footer #footer-menu',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'margin-left',
                'property'      => 'margin-left',
                'element'       => 'site-footer #footer-menu',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'margin-right',
                'property'      => 'margin-right',
                'element'       => 'site-footer #footer-menu',
            ],
        ],
    ],
];
foreach ( $fields as $field_id => $field_args ) {
    // Settings
    $field_args['settings'] = str_replace( '-', '_', $field_id );

    Kirki::add_field( 'verve-blog', $field_args );
}